@@ -5,16 +5,20 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-#ifndef __IXION_FORMULA_OPCODE_HPP__
-#define __IXION_FORMULA_OPCODE_HPP__
+#ifndef INCLUDED_IXION_FORMULA_OPCODE_HPP
+#define INCLUDED_IXION_FORMULA_OPCODE_HPP
 
 namespace ixion {
 
 /** formula opcode type */
-enum fopcode_t {
+enum fopcode_t
+{
+    fop_unknown = 0,
+
     // data types
     fop_single_ref,
     fop_range_ref,
+    fop_table_ref,
     fop_named_expression,
     fop_string,
     fop_value,
@@ -25,6 +29,10 @@ enum fopcode_t {
     fop_minus,
     fop_divide,
     fop_multiply,
+    fop_exponent,
+
+    // string operators
+    fop_concat,
 
     // relational operators
     fop_equal,
@@ -38,14 +46,16 @@ enum fopcode_t {
     fop_open,
     fop_close,
     fop_sep,
+    fop_array_row_sep,
+    fop_array_open,
+    fop_array_close,
 
-    // error conditions
-    fop_err_no_ref,
-
-    fop_unknown
+    // special conditions
+    fop_error, //< used to signify a special set of tokens representing formula cell with error.
 };
 
 }
 
 #endif
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
